@@ -1,14 +1,16 @@
 """Helper functions used throughout Cookiecutter."""
 import contextlib
-import errno
 import logging
 import os
 import shutil
 import stat
 import sys
+import tempfile
+from pathlib import Path
+
+from jinja2.ext import Extension
 
 from cookiecutter.prompt import read_user_yes_no
-from jinja2.ext import Extension
 
 logger = logging.getLogger(__name__)
 
@@ -31,19 +33,16 @@ def rmtree(path):
     shutil.rmtree(path, onerror=force_delete)
 
 
-def make_sure_path_exists(path):
+def make_sure_path_exists(path: "os.PathLike[str]") -> None:
     """Ensure that a directory exists.
 
-    :param path: A directory path.
+    :param path: A directory tree path for creation.
     """
-    logger.debug('Making sure path exists: %s', path)
+    logger.debug('Making sure path exists (creates tree if not exist): %s', path)
     try:
-        os.makedirs(path)
-        logger.debug('Created directory at: %s', path)
-    except OSError as exception:
-        if exception.errno != errno.EEXIST:
-            return False
-    return True
+        Path(path).mkdir(parents=True, exist_ok=True)
+    except OSError as error:
+        raise OSError(f'Unable to create directory at {path}') from error
 
 
 @contextlib.contextmanager
@@ -86,8 +85,8 @@ def prompt_and_delete(path, no_input=False):
         ok_to_delete = True
     else:
         question = (
-            "You've downloaded {} before. Is it okay to delete and re-download it?"
-        ).format(path)
+            f"You've downloaded {path} before. Is it okay to delete and re-download it?"
+        )
 
         ok_to_delete = read_user_yes_no(question, 'yes')
 
@@ -118,3 +117,13 @@ def simple_filter(filter_function):
 
     SimpleFilterExtension.__name__ = filter_function.__name__
     return SimpleFilterExtension
+
+
+def create_tmp_repo_dir(repo_dir: "os.PathLike[str]") -> Path:
+    """Create a temporary dir with a copy of the contents of repo_dir."""
+    repo_dir = Path(repo_dir) if isinstance(repo_dir, str) else repo_dir
+    base_dir = tempfile.mkdtemp(prefix='cookiecutter')
+    new_dir = f"{base_dir}/{repo_dir.name}"
+    logger.debug(f'Copying repo_dir from {repo_dir} to {new_dir}')
+    shutil.copytree(repo_dir, new_dir)
+    return Path(new_dir)
